@@ -26,14 +26,14 @@
 // lib
 #include "abstractbytearraycolumntextrenderer.h"
 // Qt
-#include <QtCore/QChar>
+#include <QChar>
 
 namespace Okteta {
 class CharCodec;
 }
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class CharByteArrayColumnTextRenderer : public AbstractByteArrayColumnTextRenderer
