@@ -39,7 +39,7 @@ void AbstractFileSystemExportJobPrivate::exportToFile()
     bool isWorkFileOk;
     if( mUrl.isLocalFile() )
     {
-        mWorkFilePath = mUrl.path(QUrl::FullyDecoded);
+        mWorkFilePath = mUrl.toLocalFile();
         mFile = new QFile( mWorkFilePath );
         isWorkFileOk = mFile->open( QIODevice::WriteOnly );
     }
